#! /usr/bin/env python
""" 
    Copyright (C) 2003 Vladimir Toncar

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

"""

from string import replace
import os.path
import sys
import getopt


helpText = """change_cvsroot.py 1.0

An utility to switch a working copy of a CVS module (or modules) to another
CVS root. It searches for and modifies all 'Root' files in the given 
directory and its subdirectories.

Available options:
-o <string> --old <string>    the old root string/substring
-n <string> --new <string>    the new root string/substring
-d <dir>    --directory <dir> run in <dir> and in all of its subdirectories
-v          --verbose         print the names of modified files
-h          --help            print help and exit

Options -o and -n are both mandatory.
If option -p is not given, the default value is the current directory.

Example:
Let us assume the current CVS root is :pserver:user@server:/home/cvsroot .
To switch it to :pserver:user@server:/cvsroot for all CVS modules in
directory Projects, run:

 change_cvsroot.py --old "/home/cvsroot" --new "/cvsroot" -d Projects -v
"""

def replace_in_strings(strs, replWhat, replWith):
        newlist = []
        for i in strs:
                newlist.append(replace(i, replWhat, replWith))
        return newlist
#end def


def replace_string_in_file(fname, replWhat, replWith, message):
        try:
                fr = open(fname, "r")
                lines = fr.readlines()
                fr.close()
                fw = open(fname, "w")
                fw.writelines(replace_in_strings(lines, replWhat, replWith))
                fw.close()
                if message != "":
                        print message, "in file", fname
        except IOError:
                pass
#end def


def modify_root(dirname, oldRoot, newRoot, message):
        fname = os.path.join(dirname, "Root")
        replace_string_in_file(fname, oldRoot, newRoot, message)
#end def


def walk_func(arg, dirname, names):
        modify_root(dirname, arg[0], arg[1], arg[2])
#end def


def main():
        try:
                opts, args = getopt.getopt(sys.argv[1:],\
                                "hvo:n:d:", \
                                ["help", "verbose", "old=", "new=", "directory="])
        except getopt.GetoptError:
                print helpText
                return

        oldRoot = None
        newRoot = None
        directory = "."
        message = ""

        for opt,arg in opts:
                if opt in ("-h", "--help"):
                        print helpText
                        return
                elif opt in ("-v", "--verbose"):
                        message = "Changed CVS root"
                elif opt in ("-o", "--old"):
                        oldRoot = arg
                elif opt in ("-n", "--new"):
                        newRoot = arg
                elif opt in ("-d", "--directory"):
                        directory = arg
        #end for

        if None in (oldRoot, newRoot):
                print "Both old and new CVS roots must be given!"
                print "Try change_cvsroot.py --help"
                return

        os.path.walk(directory, walk_func, [oldRoot, newRoot, message])

#end def


if __name__ == '__main__': main()






